package parse

// Builtins contains a slice of all built-in Go types.
var Builtins = []string{
	"bool",
	"byte",
	"complex128",
	"complex64",
	"error",
	"float32",
	"float64",
	"int",
	"int16",
	"int32",
	"int64",
	"int8",
	"rune",
	"string",
	"uint",
	"uint16",
	"uint32",
	"uint64",
	"uint8",
	"uintptr",
}

// Numbers contains a slice of all built-in number types.
var Numbers = []string{
	"float32",
	"float64",
	"int",
	"int16",
	"int32",
	"int64",
	"int8",
	"uint",
	"uint16",
	"uint32",
	"uint64",
	"uint8",
}
