// This file was automatically generated by genny.
// Any changes will be lost if this file is regenerated.
// see https://github.com/cheekybits/genny

package gogenerate

type StringStringMap map[string]string

func NewStringStringMap() map[string]string {
	return make(map[string]string)
}

type StringIntMap map[string]int

func NewStringIntMap() map[string]int {
	return make(map[string]int)
}

type IntStringMap map[int]string

func NewIntStringMap() map[int]string {
	return make(map[int]string)
}

type IntIntMap map[int]int

func NewIntIntMap() map[int]int {
	return make(map[int]int)
}
