// This file was automatically generated by genny.
// Any changes will be lost if this file is regenerated.
// see https://github.com/cheekybits/genny

package numbers

func IntMax(a, b int) int {
	if a > b {
		return a
	}
	return b
}
