// This file was automatically generated by genny.
// Any changes will be lost if this file is regenerated.
// see https://github.com/cheekybits/genny

package unexported

import "fmt"

func myTypeInspect(s *myType) string {
	return fmt.Sprintf("%#v", s)
}
